@@ -1,11 +1,9 @@
 from colorama import Fore, Back, Style
 
-def output(outputHandler: dict):
+def output(outputHandler: dict) -> None:
 	handler = {}
 
-	handler["error"] = False
-	handler["warning"] = False
-	handler["verbose"] = False
+	handler["type"] = ""
 
 	# Prints these style-unaffected strings before and after the main part
 	handler["before"] = ""
@@ -19,13 +17,17 @@ def output(outputHandler: dict):
 
 	handler.update(outputHandler)
 
-	if handler["error"]:
+	if handler["type"] == "error":
 		outputStyle = handler["errorStyle"]
 	
-	elif handler["warning"]:
+	elif handler["type"] == "warning":
 		outputStyle = handler["warningStyle"]
 
-	elif handler["verbose"]:
+	elif handler["type"] == "verbose":
 		outputStyle = handler["verboseStyle"]
 
+	else:
+		output({"type": "warning", "string": "OUTPUT MISCONFIGURED. PLEASE REFER TO THE DOCUMENTATION.", "before": handler["before"], "after": handler["after"]})
+		outputStyle = ""
+
 	print(handler["before"] + outputStyle + handler["string"] + " " + Style.RESET_ALL + handler["after"])
\ No newline at end of file
